<?php
use CRM_Contactcats_ExtensionUtil as E;

return [
  'name' => 'ContactCategory',
  'table' => 'civicrm_contact_category',
  'class' => 'CRM_Contactcats_DAO_ContactCategory',
  'getInfo' => fn() => [
    'title' => E::ts('Contact Category'),
    'title_plural' => E::ts('Contact Categories'),
    'description' => E::ts('Stores a category for each contact'),
    'log' => FALSE,
  ],
  'getIndices' => fn() => [
    'index_category_definition_id' => [
      'fields' => [
        'category_definition_id' => TRUE,
      ],
    ],
  ],
  'getFields' => fn() => [
    'id' => [
      'title' => E::ts('ID'),
      'sql_type' => 'int unsigned',
      'input_type' => 'Number',
      'required' => TRUE,
      'description' => E::ts('Unique ID, corresponds to contact id'),
      'primary_key' => TRUE,
      'auto_increment' => TRUE,
    ],
    'contact_id' => [
      'title' => E::ts('Contact ID'),
      'sql_type' => 'int unsigned',
      'input_type' => 'EntityRef',
      'required' => TRUE,
      'description' => E::ts('Same as id but for FormBuilder'),
      'input_attrs' => [
        'label' => E::ts('Contact'),
      ],
      'entity_reference' => [
        'entity' => 'Contact',
        'key' => 'id',
        'on_delete' => 'CASCADE',
      ],
    ],
    'category_definition_id' => [
      'title' => E::ts('Category Definition'),
      'sql_type' => 'int unsigned',
      'required' => TRUE,
      'default' => 0,
      'input_type' => 'EntityRef',
      'entity_reference' => [
        'entity' => 'ContactCategoryDefinition',
        'key' => 'id',
        'on_delete' => 'CASCADE',
      ],
    ],
    'next_category' => [
      'title' => E::ts('Next Category'),
      'sql_type' => 'int unsigned',
      'required' => TRUE,
      'default' => 0,
      'input_type' => 'Hidden', /* not needed to be exposed */
    ],
  ],
];
